%define section   free
%define base_name commons-chain
%define jakarta_version 1.0

Name:           jakarta-%{base_name}
Version:        %{jakarta_version}
Release:        1jpp
Epoch:          0
Summary:        Commons Chain
License:        Apache License 2.0
Url:            http://jakarta.apache.org/commons/sandbox/chain/
Group:          Development/Libraries/Java
Vendor:         JPackage Project
Distribution:	JPackage
Source0:	%{base_name}-%{version}-src.tar.gz
Source1:        pom-maven2jpp-depcat.xsl
Source2:        pom-maven2jpp-newdepmap.xsl
Source3:        pom-maven2jpp-mapdeps.xsl
Source4:        %{base_name}-%{version}-jpp-depmap.xml
Source5:        commons-build.tar.gz
Patch0:         commons-chain-1.0-project_xml.patch

BuildRequires:  ant >= 0:1.6, jpackage-utils >= 0:1.6
BuildRequires:	junit, maven, saxon, saxon-scripts
BuildRequires:	jakarta-commons-beanutils
BuildRequires:	jakarta-commons-digester
BuildRequires:	jakarta-commons-logging
BuildRequires:	myfaces
BuildRequires:	portlet-1.0-api
BuildRequires:	servletapi4
Requires:	jakarta-commons-beanutils
Requires:	jakarta-commons-digester
Requires:	jakarta-commons-logging
Requires:	myfaces
Requires:	portlet-1.0-api
Requires:	servletapi4
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-buildroot

%description
A popular technique for organizing the execution of complex 
processing flows is the "Chain of Responsibility" pattern, as 
described (among many other places) in the classic "Gang of Four" 
design patterns book. Although the fundamental API contracts 
required to implement this design patten are extremely simple, 
it is useful to have a base API that facilitates using the pattern, 
and (more importantly) encouraging composition of command 
implementations from multiple diverse sources.
Towards that end, the Chain API models a computation as a series 
of "commands" that can be combined into a "chain". The API for a 
command consists of a single method (execute()), which is passed 
a "context" parameter containing the dynamic state of the 
computation, and whose return value is a boolean that determines 
whether or not processing for the current chain has been completed 
(true), or whether processing should be delegated to the next 
command in the chain (false).



%package javadoc
Summary:	Javadoc for %{name}
Group:		Development/Documentation

%description javadoc
%{summary}.

%prep
rm -rf $RPM_BUILD_ROOT
%setup -q -n %{base_name}-%{version}
#find . -name "*.jar" -exec rm -f {} \;
for j in $(find . -name "*.jar"); do
	mv $j $j.no
done
gzip -dc %{SOURCE5} | tar xf -

%patch0 -b .sav

export DEPCAT=$(pwd)/%{base_name}-%{version}-depcat.new.xml
echo '<?xml version="1.0" standalone="yes"?>' > $DEPCAT
echo '<depset>' >> $DEPCAT
for p in $(find . -name project.xml); do
    pushd $(dirname $p)
    /usr/bin/saxon project.xml %{SOURCE1} >> $DEPCAT
    popd
done
echo >> $DEPCAT
echo '</depset>' >> $DEPCAT
/usr/bin/saxon $DEPCAT %{SOURCE2} > %{base_name}-%{version}-depmap.new.xml


%build
for p in $(find . -name project.xml); do
    pushd $(dirname $p)
    cp project.xml project.xml.orig
    /usr/bin/saxon -o project.xml project.xml.orig %{SOURCE3} map=%{SOURCE4}
    popd
done

for p in $(find . -name project.properties); do
    echo >> $p
    echo maven.repo.remote=file:/usr/share/maven-1.0/repository >> $p
    echo maven.home.local=$(pwd)/.maven >> $p
done

mkdir -p .maven/repository/maven/jars
build-jar-repository .maven/repository/maven/jars \
maven-jelly-tags \

mkdir -p .maven/repository/JPP/jars
build-jar-repository -s -p .maven/repository/JPP/jars \
commons-beanutils \
commons-digester \
commons-logging \
junit \
myfaces/myfaces-jsf-api \
portlet-1.0-api \
servletapi4 \


maven -Dmaven.javadoc.source=1.4 -Dmaven.home.local=$(pwd)/.maven jar javadoc 


%install
# jars
install -d -m 755 $RPM_BUILD_ROOT%{_javadir}
install -m 644 target/%{base_name}-%{version}.jar \
           $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar

(cd $RPM_BUILD_ROOT%{_javadir} && for jar in jakarta-*; do \
ln -sf ${jar} ${jar/jakarta-/}; done)
(cd $RPM_BUILD_ROOT%{_javadir} && for jar in *-%{version}*; do \
ln -sf ${jar} ${jar/-%{version}/}; done)

# javadoc
install -d -m 755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
cp -pr target/docs/apidocs/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name} # ghost symlink
rm -rf target/docs/apidocs

## manual
install -d -m 755 $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}
cp -p LICENSE.txt $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}

%clean
rm -rf $RPM_BUILD_ROOT

%post javadoc
ln -sf %{name}-%{version} %{_javadocdir}/%{name}
 
%postun javadoc
if [ "$1" = "0" ]; then
  rm -f %{_javadocdir}/%{name}
fi

%files
%defattr(0644,root,root,0755)
%{_docdir}/%{name}-%{version}/LICENSE.txt
%{_javadir}/*

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{version}

%changelog
* Wed Oct 18 2005 Ralph Apel <r.apel@r-apel.de> 0:1.0-1jpp
- First release
